@@ -78,13 +78,7 @@ fn generate_lib_rs<'world>(
     capabilities: &[(&Name, &Source, &Outputs)],
     proc_blocks: &[(&Name, &ProcBlock)],
     outputs: &[(&Name, &Sink)],
-    pipeline_nodes: &[(
-        &Entity,
-        &Name,
-        Option<&Inputs>,
-        Option<&Outputs>,
-        &PipelineNode,
-    )],
+    pipeline_nodes: &[Node<'_>],
     tensors: &[(&Entity, &Tensor, Option<&Inputs>, Option<&Outputs>)],
     mut get_name: impl FnMut(Entity) -> Option<&'world Name>,
     mut get_tensor: impl FnMut(Entity) -> Option<&'world Tensor>,
@@ -126,13 +120,7 @@ fn generate_manifest_function<'world, F, T>(
     capabilities: &[(&Name, &Source, &Outputs)],
     proc_blocks: &[(&Name, &ProcBlock)],
     outputs: &[(&Name, &Sink)],
-    pipeline_nodes: &[(
-        &Entity,
-        &Name,
-        Option<&Inputs>,
-        Option<&Outputs>,
-        &PipelineNode,
-    )],
+    pipeline_nodes: &[Node<'_>],
     tensors: &[(&Entity, &Tensor, Option<&Inputs>, Option<&Outputs>)],
     get_name: &mut F,
     get_tensor: &mut T,
@@ -153,6 +141,7 @@ where
     quote! {
         #[no_mangle]
         pub extern "C" fn _manifest() -> i32 {
+            let _setup = hotg_runicos_base_wasm::SetupGuard::default();
             #capabilities
             #proc_blocks
             #models
@@ -245,7 +234,10 @@ fn execute_output(
     let name = Ident::new(name, Span::call_site());
     let inputs = input_bindings(&inputs.tensors, tensor_names);
 
+    let msg = format!("Sending results to the \"{}\" output", name);
+
     quote! {
+        log::debug!(#msg);
         #name.consume(#inputs);
     }
 }
@@ -262,7 +254,10 @@ fn execute_model_or_proc_block(
     let output_types = tensor_types(&outputs.tensors, tensors);
     let outputs = tensor_name_or_tuple(&outputs.tensors, tensor_names);
 
+    let msg = format!("Executing \"{}\"", name);
+
     quote! {
+        log::debug!(#msg);
         let #outputs: #output_types = #name.transform(#inputs);
     }
 }
@@ -280,7 +275,7 @@ fn input_bindings(
     }
 }
 
-fn tensor_types<'world>(
+fn tensor_types(
     tensors: &[Entity],
     all_tensors: &[(&Entity, &Tensor, Option<&Inputs>, Option<&Outputs>)],
 ) -> TokenStream {
@@ -342,7 +337,12 @@ fn execute_capability(
     let output_types = tensor_types(&outputs.tensors, tensors);
     let outputs = tensor_name_or_tuple(&outputs.tensors, tensor_names);
 
-    quote! { let #outputs: #output_types = #name.generate(); }
+    let msg = format!("Reading data from \"{}\"", name);
+
+    quote! {
+        log::debug!(#msg);
+        let #outputs: #output_types = #name.generate();
+    }
 }
 
 #[derive(Debug, Default)]
@@ -359,15 +359,17 @@ struct ExecutionOrder<'world> {
             Option<&'world Outputs>,
         ),
     >,
-    tensors: &'world [(
-        &'world Entity,
-        &'world Tensor,
-        Option<&'world Inputs>,
-        Option<&'world Outputs>,
-    )],
     tensor_inputs: HashMap<Entity, &'world [Entity]>,
 }
 
+type Node<'world> = (
+    &'world Entity,
+    &'world Name,
+    Option<&'world Inputs>,
+    Option<&'world Outputs>,
+    &'world PipelineNode,
+);
+
 impl<'world> ExecutionOrder<'world> {
     /// Given a set of pipeline nodes, determine the order they should be
     /// executed in and variable names for the various tensors involved.
@@ -382,13 +384,7 @@ impl<'world> ExecutionOrder<'world> {
     ///
     /// [topo]: https://www.geeksforgeeks.org/topological-sorting/
     fn calculate(
-        pipeline_nodes: &'world [(
-            &'world Entity,
-            &'world Name,
-            Option<&'world Inputs>,
-            Option<&'world Outputs>,
-            &'world PipelineNode,
-        )],
+        pipeline_nodes: &'world [Node<'world>],
         tensors: &'world [(
             &'world Entity,
             &'world Tensor,
@@ -407,7 +403,6 @@ impl<'world> ExecutionOrder<'world> {
                     (*ent, (name, inputs, outputs))
                 })
                 .collect(),
-            tensors,
             tensor_inputs: tensors
                 .iter()
                 .copied()
@@ -678,7 +673,7 @@ fn value_to_tokens(value: &Value) -> TokenStream {
     match value {
         Value::Int(i) => i.into_token_stream(),
         Value::Float(f) => f.into_token_stream(),
-        Value::String(ResourceOrString::String(s)) if s.starts_with("@") => {
+        Value::String(ResourceOrString::String(s)) if s.starts_with('@') => {
             s[1..].parse().unwrap()
         },
         Value::String(ResourceOrString::String(s)) => s.into_token_stream(),
@@ -925,8 +920,8 @@ mod tests {
         let mut pretty = String::new();
         stdout.read_to_string(&mut pretty).unwrap();
 
-        let opening_curly = pretty.find("{").unwrap();
-        let closing_curly = pretty.rfind("}").unwrap();
+        let opening_curly = pretty.find('{').unwrap();
+        let closing_curly = pretty.rfind('}').unwrap();
 
         pretty[opening_curly + 1..closing_curly].trim().to_string()
     }
@@ -1046,6 +1041,7 @@ mod tests {
         let got = execute_capability(&name, &outputs, &tensor_names, tensors);
 
         let should_be = quote! {
+            log::debug!("Reading data from \"first\"");
             let first_0: Tensor<f32> = first.generate();
         };
         assert_quote_eq!(got, should_be);
@@ -1088,6 +1084,7 @@ mod tests {
         );
 
         let should_be = quote! {
+            log::debug!("Executing \"model\"");
             let model_output: Tensor<f32> = model.transform(model_input.clone());
         };
         assert_quote_eq!(got, should_be);
@@ -1123,6 +1120,7 @@ mod tests {
         let got = execute_output(&name, &inputs, &tensor_names);
 
         let should_be = quote! {
+            log::debug!("Sending results to the \"serial\" output");
             serial.consume((first_input.clone(), second_input.clone()));
         };
         assert_quote_eq!(got, should_be);
